@@ -3,16 +3,27 @@ import psycopg2
 from sqlalchemy import create_engine
 
 from maisaedu_utilities_prefect.dw import get_red_credentials
-from .Types import DEV, LOCAL, IAM_ROLE
+from .Types import DEV, LOCAL, POSTGRES, SQLSERVER, get_iam_role
 
 
 class Connector:
     def __init__(self, env, s3_credentials, source_credentials, target_credentials):
         self.source_credentials = source_credentials
+        self.__set_source_conn_type()
         self.target_credentials = target_credentials
         self.s3_credentials = s3_credentials
         self.env = env
-        self.iam_role = IAM_ROLE
+        self.iam_role = get_iam_role(env)
+
+    def __set_source_conn_type(self):
+        if self.source_credentials is None: 
+            self.source_conn_type = None
+        else:
+            if 'type' not in self.source_credentials:
+                self.source_conn_type = POSTGRES
+            else:
+                self.source_conn_type = self.source_credentials['type']
+
 
     def connect_target(self):
         if self.target_credentials is None:
@@ -48,10 +59,14 @@ class Connector:
         self.s3_session = session.resource("s3")
 
     def connect_source(self):
-        engine = create_engine(
-            f"postgresql+psycopg2://{self.source_credentials['user']}:{self.source_credentials['password']}@{self.source_credentials['host']}:{self.source_credentials['port']}/{self.source_credentials['database']}"
-        )
-        self.source_conn = engine.connect().execution_options(stream_results=True)
+        if self.source_conn_type == POSTGRES:
+            engine = create_engine(
+                f"postgresql+psycopg2://{self.source_credentials['user']}:{self.source_credentials['password']}@{self.source_credentials['host']}:{self.source_credentials['port']}/{self.source_credentials['database']}"
+            )
+            self.source_conn = engine.connect().execution_options(stream_results=True)
+        elif self.source_conn_type == SQLSERVER:
+            print("SQLSERVER")
+            # TODO
 
     def close_source(self):
         self.source_conn.close()
