@@ -1,4 +1,5 @@
 from maisaedu_utilities_prefect.constants.env import LOCAL, DEV, PROD
+from maisaedu_utilities_prefect.constants.redshift import get_iam_role
 
 LOGGER_PREFECT = "prefect"
 
@@ -15,8 +16,8 @@ SAVED_REDSHIFT = "saved-redshift"
 
 S3 = "s3"
 REDSHIFT = "redshift"
-
-IAM_ROLE = "arn:aws:iam::977647303146:role/service-role/AmazonRedshift-CommandsAccessRole-20220714T104138"
+POSTGRES = "postgres"
+SQLSERVER = "sqlserver"
 
 MAX_VARCHAR_LENGTH = 60000
 
