@@ -1,4 +1,3 @@
-from maisaedu_utilities_prefect.secrets import get_cipher_key
 from ..Types import PROD
 
 
@@ -8,13 +7,6 @@ class GenericWriter:
         self.struct = struct
         self.migrator_redshift_connector = migrator_redshift_connector
         self.logger = logger
-        self.__set_cipher_key()
-
-    def __set_cipher_key(self):
-        if self.migrator_redshift_connector.env == PROD:
-            self.cipher_key = None
-        else:
-            self.cipher_key = get_cipher_key(self.env)
 
     def set_temp_target_relation(self):
         self.temp_target_relation = (
@@ -33,6 +25,23 @@ class GenericWriter:
             """
         )
 
+    def create_table_temp_target_relation_to_remove_dups(self):
+        pk_columns = ", ".join(self.struct.columns_upsert)
+
+        self.target_cursor.execute(
+            f"""
+                create temp table {self.temp_target_relation} as (
+                    SELECT distinct a.* FROM {self.target_relation} as a
+                    join (
+                        SELECT {pk_columns}, count(*) FROM {self.target_relation} 
+                        group by {pk_columns} having count(*) > 1
+                    ) as subselect 
+                        on 1=1 
+                        {self.create_statement_comparison_pk_columns('subselect', 'a')}
+                );
+            """
+        )
+
     def copy_data_to_target(self, url, target):
         self.target_cursor.execute(
             f"""
@@ -61,7 +70,7 @@ class GenericWriter:
                     DELETE FROM {self.target_relation}
                     USING {self.temp_target_relation}
                     WHERE 1=1
-                        {self.create_statement_delete(self.target_relation, self.temp_target_relation)}
+                        {self.create_statement_comparison_pk_columns(self.target_relation, self.temp_target_relation)}
                     ;
                 """
         )
@@ -86,7 +95,7 @@ class GenericWriter:
                 return "SERIALIZETOJSON"
         return ""
 
-    def create_statement_delete(self, target_relation, temp_target_relation):
+    def create_statement_comparison_pk_columns(self, target_relation, temp_target_relation):
         statement_upsert = ""
         for c in self.struct.columns_upsert:
             statement_upsert = (
@@ -97,6 +106,23 @@ class GenericWriter:
             )
 
         return statement_upsert
+    
+    def clean_duplicate_inconsistencies(self):
+        cursor = self.migrator_redshift_connector.target_conn.cursor()
+
+        self.target_cursor = cursor
+
+        self.migrator_redshift_connector.target_conn.autocommit = False
+
+        self.set_temp_target_relation()
+        self.set_target_relation()
+        self.create_table_temp_target_relation_to_remove_dups()
+        self.delete_using_temp_target_from_target()
+        self.insert_data_from_temp_to_target()
+        self.drop_table_temp_target_relation()
+
+        self.migrator_redshift_connector.target_conn.commit()
+        self.migrator_redshift_connector.target_conn.autocommit = True
 
     def save_to_redshift(self, operations):
         cursor = self.migrator_redshift_connector.target_conn.cursor()
