@@ -15,7 +15,7 @@ class WriterCDC(GenericWriter, WriterInterface):
     def save_data_on_tmp_s3(self, bucket, df, path_file, file_name):
         def save_data_on_tmp(op, df, path_file):
             df = self.get_op_rows(df, op=op)
-            adapter = AdapterSourceTarget(self.struct, self.cipher_key)
+            adapter = AdapterSourceTarget(self.struct)
             df = adapter.convert_types(df)
             df = adapter.transform_data(df)
             df = adapter.equalize_number_columns(df)
